==> haskell-hslua-module-path-1.1.0-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-path
version:              1.1.0
visibility:           public
id:                   hslua-module-path-1.1.0-El2WvqUVEozEAfA6cKE0nn
key:                  hslua-module-path-1.1.0-El2WvqUVEozEAfA6cKE0nn
license:              MIT
copyright:            © 2020-2023 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file paths.
description:
    Lua module to work with file paths in a platform
    independent way.

category:             Foreign
abi:                  e5cfd2b49758363c3ce1b4bce9ae2c6c
exposed:              True
exposed-modules:      HsLua.Module.Path
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-path-1.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-path-1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-path
hs-libraries:         HShslua-module-path-1.1.0-El2WvqUVEozEAfA6cKE0nn
depends:
    base-4.16.4.0 filepath-1.4.2.2
    hslua-core-2.3.1-777UADJFM7tGoBZHSEM2Wb
    hslua-marshalling-2.3.1-EVwxTaJ2lUw1GbUN2Ktkk8
    hslua-packaging-2.3.1-4CqDLKknSAOHQCd019j6jg text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-path/html/hslua-module-path.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-path/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-path-1.1.0-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-path
version:              1.1.0
visibility:           public
id:                   hslua-module-path-1.1.0-AMrwCKSneu7Brr5FtbXiOz
key:                  hslua-module-path-1.1.0-AMrwCKSneu7Brr5FtbXiOz
license:              MIT
copyright:            © 2020-2023 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file paths.
description:
    Lua module to work with file paths in a platform
    independent way.

category:             Foreign
abi:                  93aa4a6d6fe4be58ef85c232799b2ba2
exposed:              True
exposed-modules:      HsLua.Module.Path
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-path-1.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-path-1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-path
hs-libraries:         HShslua-module-path-1.1.0-AMrwCKSneu7Brr5FtbXiOz
depends:
    base-4.16.4.0 filepath-1.4.2.2
    hslua-core-2.3.1-IxMDsbytAuM1HrMVpwgrKy
    hslua-marshalling-2.3.1-4MEdFsZjEWq2yQXjBPkQrB
    hslua-packaging-2.3.1-BeAsn1Ec1xRBdcfFv40IrC text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-path/html/hslua-module-path.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-path/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
